=== modified file 'client/include.am'
--- client/include.am	2011-06-09 12:08:38 +0000
+++ client/include.am	2011-07-26 16:13:43 +0000
@@ -60,7 +60,10 @@
                  client/user_detect.h \
                  client/wakeup.h
 
-client_drizzle_SOURCES=		client/drizzle.cc client/linebuffer.cc
+client_drizzle_SOURCES= \
+			client/drizzle.cc \
+			client/linebuffer.cc \
+			client/server_detect.cc
 client_drizzle_CXXFLAGS=	${AM_CXXFLAGS} ${LIBDRIZZLE_CPPFLAGS}
 client_drizzle_LDADD=		${READLINE_LIBS} ${BOOST_LIBS} \
 				libdrizzle-2.0/libdrizzle/libdrizzle-2.0.la \
@@ -73,7 +76,8 @@
 			    client/drizzledump.cc \
 			    client/drizzledump_data.cc \
 			    client/drizzledump_drizzle.cc \
-			    client/drizzledump_mysql.cc
+			    client/drizzledump_mysql.cc \
+			    client/server_detect.cc
 
 client_drizzledump_LDADD=	${CLIENT_LDADD} ${BOOST_LIBS}
 

=== added file 'client/server_detect.cc'
--- client/server_detect.cc	1970-01-01 00:00:00 +0000
+++ client/server_detect.cc	2011-07-26 16:13:43 +0000
@@ -0,0 +1,50 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ * vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 Andrew Hutchings
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "client_priv.h"
+
+#include <iostream>
+#include <client/server_detect.h>
+
+ServerDetect::ServerDetect(drizzle_con_st *connection) :
+  type(SERVER_UNKNOWN_FOUND),
+  version("")
+{
+  boost::match_flag_type flags = boost::match_default;
+
+  boost::regex mysql_regex("^([3-9]\\.[0-9]+\\.[0-9]+)");
+  boost::regex drizzle_regex("^(20[0-9]{2}\\.(0[1-9]|1[012])\\.[0-9]+)");
+
+  version= drizzle_con_server_version(connection);
+
+  if (regex_search(version, drizzle_regex, flags))
+  {
+    type= SERVER_DRIZZLE_FOUND;
+  }
+  else if (regex_search(version, mysql_regex, flags))
+  {
+    type= SERVER_MYSQL_FOUND;
+  }
+  else
+  {
+    std::cerr << "Server version not detectable. Assuming MySQL." << std::endl;
+    type= SERVER_MYSQL_FOUND;
+  }
+}

=== modified file 'client/server_detect.h'
--- client/server_detect.h	2011-07-25 04:35:53 +0000
+++ client/server_detect.h	2011-07-26 16:13:43 +0000
@@ -35,31 +35,7 @@
     server_type getServerType() { return type; }
     std::string& getServerVersion() { return version; }
 
-    ServerDetect(drizzle_con_st *connection) :
-      type(SERVER_UNKNOWN_FOUND),
-      version("")
-    {
-      boost::match_flag_type flags = boost::match_default;
-
-      boost::regex mysql_regex("^([3-9]\\.[0-9]+\\.[0-9]+)");
-      boost::regex drizzle_regex("^(20[0-9]{2}\\.(0[1-9]|1[012])\\.[0-9]+)");
-
-      version= drizzle_con_server_version(connection);
-
-      if (regex_search(version, drizzle_regex, flags))
-      {
-        type= SERVER_DRIZZLE_FOUND;
-      }
-      else if (regex_search(version, mysql_regex, flags))
-      {
-        type= SERVER_MYSQL_FOUND;
-      }
-      else
-      {
-        std::cerr << "Server version not detectable. Assuming MySQL." << std::endl;
-        type= SERVER_MYSQL_FOUND;
-      }
-    }
+    ServerDetect(drizzle_con_st *connection);
 
   private:
     server_type type;

=== modified file 'drizzled/include.am'
--- drizzled/include.am	2011-07-08 21:39:07 +0000
+++ drizzled/include.am	2011-07-26 16:13:43 +0000
@@ -1010,7 +1010,7 @@
 	sed "s/#include <unistd.h>//g" drizzled/generated_probes.h.bak > drizzled/generated_probes.h
 	rm drizzled/generated_probes.h.bak
 	sed -e 's,void \*,const void \*,g' drizzled/generated_probes.h | \
-		sed -e 's,char \*,const char \*,g' | tr '\t' ' ' > dtrace_probes.tmp
+		sed -e 's,char \*,const char \*,g' | sed -e 's,const const ,const ,g' | tr '\t' ' ' > dtrace_probes.tmp
 	mv dtrace_probes.tmp drizzled/generated_probes.h
 
 

=== modified file 'drizzled/module/library.cc'
--- drizzled/module/library.cc	2011-07-05 12:15:12 +0000
+++ drizzled/module/library.cc	2011-07-26 16:13:43 +0000
@@ -134,7 +134,7 @@
   if (sym == NULL)
   {
     const char* errmsg= dlerror();
-    errmsg_printf(error::ERROR, errmsg);
+    errmsg_printf(error::ERROR, "%s", errmsg);
     errmsg_printf(error::ERROR, ER(ER_CANT_FIND_DL_ENTRY),
                   plugin_decl_sym.c_str(), dlpath.c_str());
     (void)dlerror();

=== modified file 'plugin/storage_engine_api_tester/storage_engine_api_tester.cc'
--- plugin/storage_engine_api_tester/storage_engine_api_tester.cc	2011-07-03 09:42:33 +0000
+++ plugin/storage_engine_api_tester/storage_engine_api_tester.cc	2011-07-26 16:13:43 +0000
@@ -23,6 +23,7 @@
 #include <drizzled/session.h> // for mark_transaction_to_rollback
 #include <string>
 #include <map>
+#include <iostream>
 #include <fstream>
 #include <drizzled/message/table.pb.h>
 #include <drizzled/internal/m_string.h>
@@ -115,11 +116,11 @@
   state_multimap_iter cur= engine_state_transitions.find(engine_state);
   if (engine_state_transitions.count(engine_state) == 0)
   {
-    cerr << "ERROR: Invalid engine state: " << engine_state << endl
-         << "This should *NEVER* happen."
-         << endl
-         << "i.e. you've really screwed it up and you should be ashamed of "
-         << "yourself." << endl;
+    std::cerr << "ERROR: Invalid engine state: " << engine_state << std::endl
+      << "This should *NEVER* happen."
+      << std::endl
+      << "i.e. you've really screwed it up and you should be ashamed of "
+      << "yourself." << std::endl;
     assert(engine_state_transitions.count(engine_state));
   }
 
@@ -134,15 +135,15 @@
   if (cur == engine_state_transitions.end()
       || new_state.compare((*cur).second))
   {
-    cerr << "ERROR: Invalid Storage Engine state transition!" << endl
-         << "Cannot go from " << engine_state << " to " << new_state << endl;
+    std::cerr << "ERROR: Invalid Storage Engine state transition!" << std::endl
+      << "Cannot go from " << engine_state << " to " << new_state << std::endl;
     assert(false);
   }
 
   engine_state= new_state;
   engine_state_history.push_back(new_state);
 
-  cerr << "\tENGINE STATE : " << engine_state << endl;
+  std::cerr << "\tENGINE STATE : " << engine_state << std::endl;
 }
 
 static const string engine_name("STORAGE_ENGINE_API_TESTER");
@@ -431,11 +432,11 @@
   state_multimap_iter cur= cursor_state_transitions.find(cursor_state);
   if (cursor_state_transitions.count(cursor_state) == 0)
   {
-    cerr << "ERROR: Invalid Cursor state: " << cursor_state << endl
-         << "This should *NEVER* happen."
-         << endl
-         << "i.e. you've really screwed it up and you should be ashamed of "
-         << "yourself." << endl;
+    std::cerr << "ERROR: Invalid Cursor state: " << cursor_state << std::endl
+      << "This should *NEVER* happen."
+      << std::endl
+      << "i.e. you've really screwed it up and you should be ashamed of "
+      << "yourself." << std::endl;
     assert(cursor_state_transitions.count(cursor_state));
   }
 
@@ -450,9 +451,9 @@
   if (cur == cursor_state_transitions.end()
       || new_state.compare((*cur).second))
   {
-    cerr << "ERROR: Invalid Cursor state transition!" << endl
+    std::cerr << "ERROR: Invalid Cursor state transition!" << std::endl
          << "Cursor " << this << "Cannot go from "
-         << cursor_state << " to " << new_state << endl;
+         << cursor_state << " to " << new_state << std::endl;
     assert(false);
   }
 
@@ -467,7 +468,7 @@
 
   engine_state_history.push_back(cursor_state_str);
 
-  cerr << "\t\tCursor " << this << " STATE : " << cursor_state << endl;
+  std::cerr << "\t\tCursor " << this << " STATE : " << cursor_state << std::endl;
 }
 
 } /* namespace drizzled */

